@@ -15,6 +15,7 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "engine.h"
+#include <cstdarg>
 
 using namespace ost;
 using namespace std;
@@ -123,7 +124,7 @@ bool Bayonne::loadPlugin(const char *prefix, const char *path)
 
         if(!canAccess(path))
         {
-                server->errlog("access", path);
+                errlog("access", "cannot load %s", path);
                 return false;
         }
 
@@ -132,7 +133,7 @@ bool Bayonne::loadPlugin(const char *prefix, const char *path)
         {
                 kv = dso->getError();
                 server->setValue(path, kv);
-                server->errlog("error", kv);
+                errlog("error", "cannot initialize %s", path);
                 return false;
         }
         server->setValue(path, "loaded");
@@ -570,3 +571,42 @@ unsigned long Bayonne::uptime(void)
 	return now - start_time;
 }
 
+void Bayonne::errlog(const char *level, const char *fmt, ...)    
+{
+        char *m;
+        char buffer[256];
+        va_list args;
+
+        va_start(args, fmt);
+        vsnprintf(buffer, sizeof(buffer) - 1, fmt, args);
+
+        m = strchr(buffer, '\n');
+        if(m)
+                *m = 0;
+ 
+        if(!stricmp(level, "debug"))
+        {
+                slog.debug() << buffer << endl;
+                return;
+        } 
+        else if(!stricmp(level, "missing"))
+                slog.warn() << buffer << endl;
+        else if(!stricmp(level, "access"))
+                slog.warn() << buffer << endl;
+        else if(!stricmp(level, "notice"))
+                slog.notice() << buffer << endl;
+        else if(!strnicmp(level, "warn", 4))
+        {
+                level = "warn";
+                slog.warn() << buffer << endl;
+        } 
+        else if(!strnicmp(level, "crit", 4))
+        {
+                level = "fatal";
+                slog.critical() << buffer << endl;
+        }
+        else
+                slog.error() << buffer << endl;
+                                                  
+	Bayonne::server->errlog(level, buffer);
+}
