@@ -983,6 +983,11 @@ public:
 	 */
 	BayonneTranslator *translator;
 
+	/**
+	 * Alternate voicelib construct.
+	 */
+	char vlib[60];
+
 	const char *extension, *voicelib, *libext, *prefixdir, *offset;
 	Encoding encoding;
 	timeout_t framing;
@@ -1028,10 +1033,10 @@ public:
 	/**
 	 * Check if a voice library is available.
 	 *
-	 * @return true if voice library can be used.
+	 * @return voice library id or NULL if invalid.
 	 * @param iso name of library to request.
 	 */
-	bool isVoicelib(const char *cp);
+	const char *getVoicelib(const char *cp);
 
 	/**
 	 * Get audio codec used.
