@@ -333,7 +333,7 @@ ScriptInterp *BayonneSession::getInterp(const char *id)
 
 ScriptSymbols *BayonneSession::getSymbols(const char *id)
 {
-	if(globalSyms && !strnicmp(id, "global.", 7))
+	if(!strnicmp(id, "global.", 7))
 	{
 		release();
 		globalLock.enter();
@@ -1100,10 +1100,10 @@ const char *BayonneSession::getAudio(bool live)
 		if(!audio.translator)
 			return "requested language not loaded";
 		
-		if(audio.isVoicelib(cp))
-			audio.voicelib = cp;
-		else
+		cp = audio.getVoicelib(cp);
+		if(!cp)
 			return "voice library invalid";
+		audio.voicelib = cp;
 	}
 	else
 	{
