@@ -545,14 +545,8 @@ bool BayonneSession::stateInput(Event *event)
 			goto input;
 		dtmf_digits[0] = 0;
 		digit_count = 0;
-#ifdef	HAVE_LIBEXEC
-		if(state.pid)
-		{
-			state.result = 1;
-			setState(STATE_LIBEXEC);
+		if(setLibexec(1))
 			return true;
-		}
-#endif
 		setSymbol(state.input.var, "", state.input.size);
 		if(scriptEvent("input:timeout"))
 		{
@@ -586,14 +580,9 @@ bool BayonneSession::stateInput(Event *event)
 		{
 			dtmf_digits[0] = 0;
 			digit_count = 0;
-#ifdef	HAVE_LIBEXEC
-			if(state.pid)
-			{
-				state.result = 2;
-				setState(STATE_LIBEXEC);
+
+			if(setLibexec(2))
 				return true;
-			}
-#endif
 
 			if(!scriptEvent("input:invalid"))
 				if(!signalScript(SIGNAL_INVALID))
