@@ -77,6 +77,7 @@ protected:
 	friend class ToneThread;
 
 	unsigned dev;			// ccAudio device copied from driver
+	AudioDevice *ad;		// staged for delete in clraudio
 
 public:
 	Session(timeslot_t ts, unsigned sc);
@@ -93,6 +94,11 @@ public:
 	bool enterRecord(Event *event);
 	bool enterTone(Event *event);
 	bool enterCommon(Event *event);
+
+	void clrAudio(void);
+
+	inline void setDevice(AudioDevice *d)
+		{ad = d;};
 };
 
 class ToneThread : public ScriptThread, public Audio, public TimerPort, public Bayonne
@@ -104,6 +110,7 @@ protected:
 	unsigned devid;
 	AudioDevice *dev;
 	Linear buffer;
+	bool resetflag;
 
 	void run(void);
 
@@ -121,6 +128,7 @@ protected:
 	unsigned devid;
 	AudioDevice *dev;
 	Linear buffer;
+	bool resetflag;
 
 	void run(void);
 
@@ -137,6 +145,7 @@ protected:
         unsigned devid;                   
 	AudioDevice *dev;
 	Linear buffer;
+	bool resetflag;
 
         void run(void);
 
