@@ -22,6 +22,17 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkKey(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "key doesnt use members";
+
+	if(!useKeywords(line, "=index=value"))
+		return "unknown keyword used for key";
+
+	return chkAllVars(line, img);
+}
+
 const char *Checks::chkCDR(Line *line, ScriptImage *img)
 {
 	char var[65];
