@@ -57,10 +57,18 @@ using namespace std;
 #define	CONFIG_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Config"
 #define	RUN_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Logs"
 #define	LIBEXEC_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne Libxec"
+
+#ifdef	DEBUG
+#define	LIBDIR_FILES	"C:\\Program Files\\GNU Telephony\\CAPE Framework\\debug"
+#define	MODULE_FILES	LIBDIR_FILES
+#define	DRIVER_FILES	LIBDIR_FILES
+#define	PHRASE_FILES	LIBDIR_FILES	
+#else	
 #define	LIBDIR_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Runtime"
 #define	MODULE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins"
 #define	DRIVER_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Drivers"
 #define	PHRASE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Languages"
+#endif
 
 #else
 #define	MODULE_FILES	LIBDIR_FILES
@@ -160,6 +168,11 @@ static void commonConfig(void)
 	keyserver.setValue("node", nodename);
 	keyserver.setValue("platform", "w32");
 	keyserver.setValue("cpu", cpu);
+
+	snprintf(path, sizeof(path), "%s/bayonne.key", keypaths.getLast("datafiles"));
+	keypaths.setValue("keysave", path);
+	snprintf(path, sizeof(path), "%s/bayonne.tmp", keypaths.getLast("datafiles"));
+	keypaths.setValue("keytemp", path);
 #else
 	struct utsname uts;
 	char hostname[128];
@@ -189,6 +202,11 @@ static void commonConfig(void)
 	}
 	else
 		keypaths.setValue("tmpfs", "/tmp/.bayonne");
+
+	snprintf(path, sizeof(path), "%s/bayonne.keys", keypaths.getLast("runfiles"));
+	keypaths.setValue("keysave", path);
+	snprintf(path, sizeof(path), "%s/.bayonne.keys", keypaths.getLast("runfiles"));
+	keypaths.setValue("keytemp", path);
 #endif
 	env = Process::getEnv("LANG");
 	if(env)
@@ -313,9 +331,15 @@ static void commonConfig(void)
 void testConfig(char *argv0)
 {
 #ifdef	WIN32
+#ifdef	DEBUG
 	keypaths.setValue("phrases", "Debug");
 	keypaths.setValue("drivers", "Debug");
 	keypaths.setValue("modules", "Debug");
+#else
+        keypaths.setValue("phrases", "Release");
+        keypaths.setValue("drivers", "Release");
+        keypaths.setValue("modules", "Release"); 
+#endif
 	keypaths.setValue("prompts", "../audio");
 	keypaths.setValue("scripts", "../scripts");
 	keypaths.setValue("config", "../config");
