@@ -546,6 +546,24 @@ bool Methods::scrTone(void)
 	return false;
 }
 
+bool Methods::scrKey(void)
+{
+	const char *cp;
+	const char *val = getKeyword("value");
+	const char *ind = getKeyword("index");
+	Symbol *sym;
+
+	while(NULL != (cp = getOption(NULL)))
+	{
+		sym = mapSymbol(cp, PersistProperty::getSize());
+		if(!sym)
+			continue;
+		PersistProperty::refresh(sym, ind, val);
+	}
+	advance();
+	return true;
+}
+
 bool Methods::scrTimeslot(void)
 {
 	const char *cp;
@@ -696,7 +714,8 @@ bool Methods::scrVoicelib(void)
 		return true;
 	}
 
-	if(!audio.isVoicelib(lib))
+	lib = audio.getVoicelib(lib);
+	if(lib == NULL)
 	{
 		slog.error("voice library %s invalid", lib);
 		error("voicelib-invalid");
