@@ -27,6 +27,8 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
+		{"key", true, (Method)&Methods::scrKey,
+			(Check)&Checks::chkKey},
 		{"dial", false, (Method)&Methods::scrDial,
 			(Check)&Checks::chkDial},
 		{"start", false, (Method)&Methods::scrStart,
@@ -190,6 +192,7 @@ ScriptRuntime()
 	ScriptInterp::addConditional("voice", &testVoice);
 	ScriptInterp::addConditional("lang", &testLang);
 	ScriptInterp::addConditional("language", &testLang);
+	ScriptInterp::addConditional("key", &testKey);
 }
 
 unsigned long Runtime::getTrapMask(const char *trapname)
@@ -256,12 +259,17 @@ void Runtime::errlog(const char *level, const char *msg)
 	char *m;
         struct tm *dt, tbuf;
         time_t now;
-        time(&now);
         int year;
-        dt = localtime_r(&now, &tbuf);
+
         static char *months[12] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
                 "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
 
+	if(!path)
+		return;
+
+        time(&now); 
+        dt = localtime_r(&now, &tbuf);  
+
         year = dt->tm_year;
         if(year < 1000)
                 year += 1900;
@@ -412,7 +420,12 @@ bool Runtime::testTimeslot(ScriptInterp *interp, const char *v)
 bool Runtime::testVoice(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
-	return s->audio.isVoicelib(v);
+	return (s->audio.getVoicelib(v) != NULL);
+}
+
+bool Runtime::testKey(ScriptInterp *interp, const char *v)
+{
+	return PersistProperty::test(v);
 }
 
 bool Runtime::testLang(ScriptInterp *interp, const char *v)
