@@ -37,6 +37,7 @@ static BOOL WINAPI stop(DWORD code)
 
 	BayonneService::stop();
 	BayonneDriver::stop();
+	PersistProperty::save();
 
 	if(code)
 		Bayonne::errlog("failed", "server exiting; reason=%d", code);
@@ -64,6 +65,7 @@ static RETSIGTYPE stop(int signo)
 
 	BayonneService::stop();
 	BayonneDriver::stop();
+	PersistProperty::save();
 
         if(signo == -2)
                 Bayonne::errlog("failed", "server exiting; no timeslots allocated");
@@ -111,11 +113,14 @@ static void loading(void)
 	unsigned count = keyoptions.getCount("modules");
 	BayonneDriver *driver;
 	BayonneTranslator *translator = NULL;
+	static char vlib[64];
 
 #ifdef	HAVE_LIBEXEC
 	Libexec::allocate();
 #endif
 
+	PersistProperty::load();
+
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
 		BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cp);  
@@ -141,6 +146,23 @@ static void loading(void)
 			Bayonne::init_translator = translator;
 			Bayonne::init_voicelib = cp;
 		}
+		else if(cp[2] == '_')
+		{
+			vlib[0] = cp[0];
+			vlib[1] = cp[1];
+			cp = strchr(cp, '/');
+			if(!cp)
+				cp = "/default";
+			snprintf(vlib + 2, sizeof(vlib) - 2, "%s", cp);
+			snprintf(buffer, sizeof(buffer), "%s/%s",
+				keypaths.getLast("prompts"), vlib);
+			if(isDir(buffer))
+			{
+                        	slog.debug("using %s as default voice library", cp);
+                        	Bayonne::init_translator = translator;
+                        	Bayonne::init_voicelib = vlib; 
+			}
+		}
         } 
 
 	driver = BayonneDriver::loadDriver(keypaths.getLast("drivers"), dname);
@@ -343,6 +365,12 @@ int main(int argc, char **argv)
 {
 	char *cp;
 
+#if defined(WIN32) && defined(DEBUG)
+        int tmpFlag = _CrtSetDbgFlag( _CRTDBG_REPORT_FLAG );
+        tmpflag |= _CRTDBG_ALLOC_MEM_DF|_CRTDBG_CHECK_ALWAYS_DF|_CRTDBG_CHECK_CRT_DF;
+	_CrtSetDbgFlag( tmpFlag );
+#endif   
+
         if(argc < 2)
         {
                 cerr << "use: bayonne --option [args...]" << endl;
